@@ -8,9 +8,9 @@ from pathlib import Path
 from attrs import define
 from loguru import logger
 
-from typedparser import VerboseQuietArgs, add_argument, TypedParser
 from packg import format_exception
 from packg.log import SHORTEST_FORMAT, configure_logger, get_logger_level_from_args
+from typedparser import TypedParser, VerboseQuietArgs, add_argument
 
 
 @define
