@@ -1,10 +1,10 @@
 from attrs import define
 from loguru import logger
 
-from typedparser import VerboseQuietArgs, TypedParser
 from packg.iotools import loads_json
 from packg.log import SHORTEST_FORMAT, configure_logger, get_logger_level_from_args
 from packg.system import systemcall_with_assert
+from typedparser import TypedParser, VerboseQuietArgs
 
 
 @define
