@@ -1,16 +1,16 @@
 import inspect
 from abc import ABCMeta, abstractmethod
 from typing import (
-    Iterator,
-    Optional,
-    List,
-    ItemsView,
-    KeysView,
-    ValuesView,
     Any,
     Dict,
+    ItemsView,
+    Iterator,
+    KeysView,
+    List,
+    Optional,
     Tuple,
     Union,
+    ValuesView,
 )
 
 
@@ -79,6 +79,17 @@ class Const(metaclass=InstanceToClassDelegator):
     # create the class properties with empty entries for the root parent
     _dict: Dict[str, Dict[str, Any]] = {"Const": {}}
 
+    @classmethod
+    def verify_value(cls, value: str, case_sensitive: bool = False) -> str:
+        if not case_sensitive and isinstance(value, str):
+            value = str(value).lower()
+            test_values = list((v.lower() if isinstance(v, str) else v) for v in cls.values())
+        else:
+            test_values = list(cls.values())
+        if value not in test_values:
+            raise ValueError(f"Value '{value}' not in {test_values} defined in {cls.__name__}")
+        return value
+
     @classmethod
     def values_list(cls) -> List[Any]:
         return list(cls.values())
