@@ -27,11 +27,18 @@ def dumps_numpy_array(arr) -> Tuple[bytes, str]:
     Returns: tuple of
         bytes: array data as bytes
         str: dtype and shape as string e.g. "float32-100,100" for a 100x100 float32 array
+             or "float64-" for a scalar (zero-dimensional array)
 
     """
+    # Handle zero-dimensional arrays (scalars)
+    if arr.ndim == 0:
+        return arr.tobytes(), f"{arr.dtype.name}-"
     return arr.tobytes(), f"{arr.dtype.name}-{','.join(str(d) for d in arr.shape)}"
 
 
 def loads_numpy_array(arr, dtype_shape) -> np.ndarray:
     dtype, shape = dtype_shape.split("-")
+    # Handle zero-dimensional arrays (scalars)
+    if not shape:
+        return np.frombuffer(arr, dtype=dtype).reshape(())
     return np.frombuffer(arr, dtype=dtype).reshape([int(s) for s in shape.split(",")])
