@@ -1,6 +1,10 @@
+"""
+utility to run a function in multiple processes with a progress bar and error handling
+"""
+
 # pylint: disable=duplicate-code
-# todo either fix duplicate-code or remove this todo comment
-# todo move the main() example outside of this file
+# TODO either fix duplicate-code or remove this TODO comment
+# TODO move the main() example outside of this file
 from __future__ import annotations
 
 import random
@@ -15,6 +19,7 @@ from loguru import logger
 
 from packg.dtime import format_seconds_adaptive
 from packg.log import configure_logger
+from packg.strings.formatters import format_float_to_fixed_length_with_variable_precision
 from packg.tqdmext import tqdm_max_ncols
 from packg.typext import NoneType
 
@@ -95,10 +100,11 @@ class FnMultiProcessor:
     def update_pbar(self, amount=1):
         self.processed += amount
         sec_per_iter = (default_timer() - self.start_time) / max(self.processed, 1)
-        desc_post = f" {sec_per_iter:10.2f} s/it"
         if sec_per_iter < 1:
             iter_per_sec = 1 / sec_per_iter
-            desc_post = f" {iter_per_sec:10.2f} it/s"
+            desc_post = f" {format_float_to_fixed_length_with_variable_precision(iter_per_sec)}it/s"
+        else:
+            desc_post = f" {format_float_to_fixed_length_with_variable_precision(sec_per_iter)}s/it"
         rem_time_fmt = ""
         if self.total is not None:
             rem_time = sec_per_iter * (self.total - self.processed)
@@ -166,8 +172,8 @@ def multi_fn_with_output(
         try:
             out = fn(*args)
         except Exception as e:
+            logger.error(f"Error in multi_function:\n\n{''.join(format_exception(e))}")
             if ignore_errors:
-                logger.error(f"Error in multi_function:\n\n{''.join(format_exception(e))}")
                 out_q.put(None)
                 continue
             raise e
