@@ -1,4 +1,4 @@
-from .systemcall import systemcall, systemcall_with_assert, assert_command_worked
+from .systemcall import assert_command_worked, systemcall, systemcall_with_assert
 
 __all__ = [
     "systemcall",
